/*
 * Wazuh Vulnerability scanner - Database Feed Manager
 * Copyright (C) 2015, Wazuh Inc.
 * Feb 28, 2023.
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public
 * License (version 2) as published by the FSF - Free Software
 * Foundation.
 */

#ifndef _GLOBALDATA_HPP
#define _GLOBALDATA_HPP

#include "json.hpp"
#include "singleton.hpp"

/**
 * @brief Class to manage global maps data.
 */
class GlobalData final : public Singleton<GlobalData>
{
    nlohmann::json m_vendorMaps;
    nlohmann::json m_osCpeMaps;
    nlohmann::json m_cnaMappings;
    std::string m_managerName;

public:
    /**
     * @brief Set vendor map data.
     * @param vendor Vendor data.
     */
    void vendorMaps(const nlohmann::json& vendor)
    {
        m_vendorMaps = vendor;
    }

    /**
     * @brief Set OS CPE map data.
     * @param osCpe OS CPE data.
     */
    void osCpeMaps(const nlohmann::json& osCpe)
    {
        m_osCpeMaps = osCpe;
    }

    /**
     * @brief Set manager name.
     * @param name Manager name.
     */
    void managerName(std::string_view name)
    {
        m_managerName = name.empty() ? "manager" : name;
    }

    /**
     * @brief Set CNA mappings.
     * @param cnaMappings CNA mappings.
     */
    void cnaMappings(const nlohmann::json& cnaMappings)
    {
        m_cnaMappings = cnaMappings;
    }

    /**
     * @brief Get vendor map data.
     * @return vendor map data.
     */
    const nlohmann::json& vendorMaps() const
    {
        return m_vendorMaps;
    }

    /**
     * @brief Get OS CPE map data.
     * @return OS CPE data.
     */
    const nlohmann::json& osCpeMaps() const
    {
        return m_osCpeMaps;
    }

    /**
     * @brief Get CNA mappings.
     * @return CNA mappings.
     */
    const nlohmann::json& cnaMappings() const
    {
        return m_cnaMappings;
    }

    /**
     * @brief Get manager name.
     * @return Manager name.
     */
    const std::string& managerName() const
    {
        return m_managerName;
    }
};

#endif // _GLOBALDATA_HPP
