/*
 * Wazuh databaseFeedManager
 * Copyright (C) 2015, Wazuh Inc.
 * September 25, 2023.
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public
 * License (version 2) as published by the FSF - Free Software
 * Foundation.
 */
#ifndef _MOCK_CONTENTREGISTER_HPP
#define _MOCK_CONTENTREGISTER_HPP

#include "gmock/gmock.h"
#include "gtest/gtest.h"

#include "json.hpp"

/**
 * @class MockContentRegister
 *
 * @brief Mock class for simulating a content register object.
 *
 * The `MockContentRegister` class is designed to simulate the behavior of a content
 * register for testing purposes. It provides mock implementations of methods and
 * allows you to set expectations on method calls and their return values for testing.
 *
 * This class is used in unit tests only to verify interactions with a content
 * register without actually performing real operations on it.
 */
class MockContentRegister
{
public:
    /**
     * @brief Constructor for creating a mock ContentRegister object.
     *
     * The `MockContentRegister` constructor initializes a new instance of the mock ContentRegister
     * class, which is used for simulating the behavior of a content register for testing purposes.
     * You can specify the `topicName` and additional `parameters` as input when creating a mock instance.
     *
     * @param topicName The name of the topic associated with the mock ContentRegister.
     * @param parameters Additional parameters provided as a JSON object.
     * @param fileProcessingCallback Callback function in charge of the file processing task.
     */
    MockContentRegister(std::string topicName,
                        const nlohmann::json parameters,
                        const FileProcessingCallback fileProcessingCallback) {};
    ~MockContentRegister() = default;

    /**
     * @brief Mock method for changeSchedulerInterval.
     *
     * @note This method is intended for testing purposes and does not perform any real action.
     */
    MOCK_METHOD(void, changeSchedulerInterval, (size_t newInterval), ());
};

#endif // _MOCK_CONTENTREGISTER_HPP
