/*
 * Wazuh databaseFeedManager
 * Copyright (C) 2015, Wazuh Inc.
 * May 7, 2024.
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public
 * License (version 2) as published by the FSF - Free Software
 * Foundation.
 */
#ifndef _MOCK_REMEDIATION_DATA_CACHE_HPP
#define _MOCK_REMEDIATION_DATA_CACHE_HPP

#include "gmock/gmock.h"
#include "gtest/gtest.h"

#include "remediationDataCache.hpp"
#include "singleton.hpp"

#include "json.hpp"

/**
 * @class MockRemediationDataCache
 *
 * @brief Mock class for simulating a database feed manager object.
 *
 * The `MockRemediationDataCache` class is designed to simulate the behavior of an
 * remediation data cache for testing purposes. It provides mock implementations of methods and
 * allows you to set expectations on method calls and their return values for testing.
 *
 * This class is used in unit tests only to verify interactions with a content
 * register without actually performing real operations on it.
 */
class MockRemediationDataCache : public Singleton<MockRemediationDataCache>
{
public:
    MockRemediationDataCache() = default;

    virtual ~MockRemediationDataCache() = default;

    /**
     * @brief Mock method for getRemediationData.
     *
     * @note This method is intended for testing purposes and does not perform any real action.
     */
    MOCK_METHOD(Remediation, getRemediationData, (const std::string& agentId), ());

    /**
     * @brief Mock method for addRemediationData.
     *
     * @note This method is intended for testing purposes and does not perform any real action.
     */
    MOCK_METHOD(void, addRemediationData, (const std::string& agentId, Remediation newRemediationData), ());
};

#endif // _MOCK_REMEDIATION_DATA_CACHE_HPP
